@@ -8,7 +8,7 @@ from django.utils.translation import ugettext_lazy as _
 
 class X509Form(forms.ModelForm):
     OPERATION_CHOICES = (
-        ('', '----- {0} -----'.format(_('Please select an option'))),
+        ('-', '----- {0} -----'.format(_('Please select an option'))),
         ('new', _('Create new')),
         ('import', _('Import Existing'))
     )
@@ -62,7 +62,8 @@ class BaseAdmin(ModelAdmin):
     def get_fields(self, request, obj=None):
         fields = super(BaseAdmin, self).get_fields(request, obj)
         # edit
-        if obj and 'extensions' in fields:
+        if obj:
+            fields = fields[:]  # make copy
             fields.remove('extensions')
         return fields
 
